@@ -1,11 +1,11 @@
-import requests
+from requests import Request, Session
 import json
 
 class URLs:
     def __init__(self, response_format="json", ):
         self.format = response_format
 
-        self.base_url = "http://13.251.45.210:80/"
+        self.base_url = "http://13.212.164.75:80/%s?limmit={}"
         self.preprocess = 'preprocess'
         self.predictSentiment = 'predictSentiment'
         self.getAspect = 'extract_aspect_words'
@@ -18,32 +18,41 @@ class URLs:
         return self.base_url
 
     def preprocess_url(self):
-        return self.base_url + self.preprocess
+        url = self.base_url % self.preprocess
+        return url
 
     def predictSentiment_url(self):
-        return self.base_url + self.predictSentiment
+        url = self.base_url % self.predictSentiment
+        return url
 
     def getAspect_url(self):
-        return self.base_url + self.getAspect
+        url =  self.base_url % self.getAspect
+        return url
 
     def getOpinion_url(self):
-        return self.base_url + self.getOpinion
+        url =  self.base_url % self.getOpinion
+        return url
 
     def getQualifier_url(self):
-        return self.base_url + self.getQualifer
+        url =  self.base_url % self.getQualifer
+        return url
 
     def getAll_url(self):
-        return self.base_url + self.getAll
+        url = self.base_url % self.getAll
+        return url
     
     def getCt_url(self):
-        return self.base_url + self.getCt
+        url = self.base_url % self.getCt
+        return url
 
 class Api():
     def __init__(self, response_format="json"):
         self.format = response_format
         self.url = URLs(response_format=response_format)
         self.header = {'Content-Type': 'application/json',
-                       'Accept': 'application/json'}
+                       'Accept': 'application/json',
+                       'Accept-Encoding': 'message/rfc822'}
+        self.session = Session()
 
     def __to_format(self, response):
         """A private method to return the API response in the desired format
@@ -66,8 +75,13 @@ class Api():
             @param self - the object pointer
             @param url - API URL to access
         """
-
-        return self.__to_format(requests.post(url, data=json.dumps(content), headers=self.header))
+        req = Request('POST',url, data=json.dumps(content), headers=self.header)
+        prep = req.prepare()
+        resq = self.session.send(prep,
+        stream=None,
+        verify=None
+        )
+        return resq 
 
     def get_preprocess(self, content):
         """Returns all of the user's accounts."""
